@@ -1,13 +1,14 @@
-/* SPDX-License-Identifier: GPL-2.0-only */
+// SPDX-FileCopyrightText: 2013 Mohamad Gebai <mohamad.gebai@polymtl.ca>
+//
+// SPDX-License-Identifier: GPL-2.0-only
+
 #if !defined(LTTNG_TRACE_KVM_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_KVM_H
 
 #include <lttng/tracepoint-event.h>
 #include <asm/vmx.h>
 #include <asm/svm.h>
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
 #include <asm/clocksource.h>
-#endif
 #include <lttng/kernel-version.h>
 #include <wrapper/kvm-x86.h>
 #include <../arch/x86/kvm/lapic.h>
@@ -149,8 +150,7 @@ LTTNG_TRACEPOINT_EVENT_CODE_MAP(kvm_exit, kvm_x86_exit,
 
 	TP_code_post()
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,16,0) || \
-	LTTNG_RHEL_KERNEL_RANGE(4,18,0,425,0,0, 4,19,0,0,0,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,16,0))
 LTTNG_TRACEPOINT_EVENT_CODE_MAP(kvm_exit, kvm_x86_exit,
 	TP_PROTO(struct kvm_vcpu *vcpu, u32 isa),
 	TP_ARGS(vcpu, isa),
@@ -183,7 +183,7 @@ LTTNG_TRACEPOINT_EVENT_CODE_MAP(kvm_exit, kvm_x86_exit,
 	TP_code_post()
 )
 #elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,10,0) || \
-	LTTNG_RHEL_KERNEL_RANGE(4,18,0,240,0,0, 4,18,0,425,0,0))
+	LTTNG_RHEL_KERNEL_RANGE(4,18,0,240,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT_CODE_MAP(kvm_exit, kvm_x86_exit,
 	TP_PROTO(unsigned int exit_reason, struct kvm_vcpu *vcpu, u32 isa),
 	TP_ARGS(exit_reason, vcpu, isa),
@@ -548,21 +548,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(kvm_emulate_insn, kvm_x86_emulate_insn,
 	TP_ARGS(vcpu, failed),
 
 	TP_FIELDS(
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
-		ctf_integer(__u64, rip, vcpu->arch.emulate_ctxt.decode.fetch.start)
-		ctf_integer(__u32, csbase, kvm_x86_ops->get_segment_base(vcpu, VCPU_SREG_CS))
-		ctf_integer(__u8, len, vcpu->arch.emulate_ctxt.decode.eip
-				- vcpu->arch.emulate_ctxt.decode.fetch.start)
-		ctf_array(__u8, insn, vcpu->arch.emulate_ctxt.decode.fetch.data, 15)
-		ctf_integer(__u8, flags, kei_decode_mode(vcpu->arch.emulate_ctxt.mode))
-#elif (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,17,0))
-		ctf_integer(__u64, rip, vcpu->arch.emulate_ctxt.fetch.start)
-		ctf_integer(__u32, csbase, kvm_x86_ops->get_segment_base(vcpu, VCPU_SREG_CS))
-		ctf_integer(__u8, len, vcpu->arch.emulate_ctxt._eip
-				- vcpu->arch.emulate_ctxt.fetch.start)
-		ctf_array(__u8, insn, vcpu->arch.emulate_ctxt.fetch.data, 15)
-		ctf_integer(__u8, flags, kei_decode_mode(vcpu->arch.emulate_ctxt.mode))
-#elif (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(5,7,0) && \
+#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(5,7,0) && \
 	!LTTNG_RHEL_KERNEL_RANGE(4,18,0,305,0,0, 4,19,0,0,0,0))
 		ctf_integer(__u64, rip, vcpu->arch.emulate_ctxt._eip -
 				(vcpu->arch.emulate_ctxt.fetch.ptr -
@@ -612,7 +598,6 @@ LTTNG_TRACEPOINT_EVENT_MAP(
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
 LTTNG_TRACEPOINT_EVENT_MAP(kvm_write_tsc_offset, kvm_x86_write_tsc_offset,
 	TP_PROTO(unsigned int vcpu_id, __u64 previous_tsc_offset,
 		 __u64 next_tsc_offset),
@@ -624,9 +609,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(kvm_write_tsc_offset, kvm_x86_write_tsc_offset,
 		ctf_integer(__u64, next_tsc_offset, next_tsc_offset)
 	)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
 #ifdef CONFIG_X86_64
 
 LTTNG_TRACEPOINT_EVENT_MAP(kvm_update_master_clock, kvm_x86_update_master_clock,
@@ -657,7 +640,6 @@ LTTNG_TRACEPOINT_EVENT_MAP(kvm_track_tsc, kvm_x86_track_tsc,
 )
 
 #endif /* CONFIG_X86_64 */
-#endif /* LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0) */
 
 #endif /* LTTNG_TRACE_KVM_H */
 
