@@ -1,4 +1,7 @@
-/* SPDX-License-Identifier: GPL-2.0-only */
+// SPDX-FileCopyrightText: 2012 Andrew Gabbasov <andrew_gabbasov@mentor.com>
+//
+// SPDX-License-Identifier: GPL-2.0-only
+
 #undef TRACE_SYSTEM
 #define TRACE_SYSTEM btrfs
 
@@ -9,10 +12,6 @@
 #include <linux/writeback.h>
 #include <lttng/kernel-version.h>
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,19,0))
-#include <../fs/btrfs/ordered-data.h>
-#endif
-
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,2,0))
 #include <../fs/btrfs/accessors.h>
 #endif
@@ -34,18 +33,14 @@ struct btrfs_delayed_data_ref;
 struct btrfs_delayed_ref_head;
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,5,0))
 struct btrfs_block_group;
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#else
 struct btrfs_block_group_cache;
 #endif
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 struct btrfs_free_cluster;
-#endif
 struct map_lookup;
 struct extent_buffer;
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
 struct extent_state;
 #endif
-#endif
 
 #define BTRFS_UUID_SIZE 16
 
@@ -649,6 +644,72 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_put,
 )
 #endif
 
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,0,0))
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_lookup,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_lookup_range,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_lookup_first_range,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_lookup_for_logging,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_lookup_first,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_split,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_dec_test_pending,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__ordered_extent, btrfs_ordered_extent_mark_finished,
+
+	TP_PROTO(const struct btrfs_inode *inode,
+		const struct btrfs_ordered_extent *ordered),
+
+	TP_ARGS(inode, ordered)
+)
+#endif
+
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,14,0))
 LTTNG_TRACEPOINT_EVENT(btrfs_writepage_end_io_hook,
 
@@ -708,43 +769,7 @@ LTTNG_TRACEPOINT_EVENT(btrfs_writepage_end_io_hook,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,17,0))
-LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__writepage,
-
-	TP_PROTO(const struct folio *folio, const struct inode *inode,
-		 const struct writeback_control *wbc),
-
-	TP_ARGS(folio, inode, wbc),
-
-	TP_FIELDS(
-		ctf_integer(ino_t, ino, inode->i_ino)
-		ctf_integer(pgoff_t, index, folio->index)
-		ctf_integer(long, nr_to_write, wbc->nr_to_write)
-		ctf_integer(long, pages_skipped, wbc->pages_skipped)
-		ctf_integer(loff_t, range_start, wbc->range_start)
-		ctf_integer(loff_t, range_end, wbc->range_end)
-		ctf_integer(char, for_kupdate, wbc->for_kupdate)
-		ctf_integer(char, range_cyclic, wbc->range_cyclic)
-		ctf_integer(pgoff_t, writeback_index,
-				inode->i_mapping->writeback_index)
-		ctf_integer(u64, root_objectid,
-				BTRFS_I(inode)->root->root_key.objectid)
-	)
-)
-
-LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs__writepage,
-
-	__extent_writepage,
-
-	btrfs__extent_writepage,
-
-	TP_PROTO(const struct folio *folio, const struct inode *inode,
-		 const struct writeback_control *wbc),
-
-	TP_ARGS(folio, inode, wbc)
-)
-
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,12,0))
 LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__writepage,
 
 	TP_PROTO(const struct folio *folio, const struct inode *inode,
@@ -837,9 +862,6 @@ LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__writepage,
 		ctf_integer(long, pages_skipped, wbc->pages_skipped)
 		ctf_integer(loff_t, range_start, wbc->range_start)
 		ctf_integer(loff_t, range_end, wbc->range_end)
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
-		ctf_integer(char, nonblocking, wbc->nonblocking)
-#endif
 		ctf_integer(char, for_kupdate, wbc->for_kupdate)
 		ctf_integer(char, for_reclaim, wbc->for_reclaim)
 		ctf_integer(char, range_cyclic, wbc->range_cyclic)
@@ -1198,7 +1220,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs_delayed_tree_ref,
 
 	TP_ARGS(ref, full_ref, action)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
+#else
 LTTNG_TRACEPOINT_EVENT_CLASS(btrfs_delayed_tree_ref,
 
 	TP_PROTO(struct btrfs_delayed_ref_node *ref,
@@ -1244,45 +1266,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs_delayed_tree_ref,
 
 	TP_ARGS(ref, full_ref, action)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,7,0))
-LTTNG_TRACEPOINT_EVENT(btrfs_delayed_tree_ref,
-
-	TP_PROTO(struct btrfs_delayed_ref_node *ref,
-		 struct btrfs_delayed_tree_ref *full_ref,
-		 int action),
-
-	TP_ARGS(ref, full_ref, action),
-
-	TP_FIELDS(
-		ctf_integer(u64, bytenr, ref->bytenr)
-		ctf_integer(u64, num_bytes, ref->num_bytes)
-		ctf_integer(int, action, action)
-		ctf_integer(u64, parent, full_ref->parent)
-		ctf_integer(u64, ref_root, full_ref->root)
-		ctf_integer(int, level, full_ref->level)
-		ctf_integer(int, type, ref->type)
-		ctf_integer(u64, seq, ref->seq)
-	)
-)
-#else
-LTTNG_TRACEPOINT_EVENT(btrfs_delayed_tree_ref,
-
-	TP_PROTO(struct btrfs_delayed_ref_node *ref,
-		 struct btrfs_delayed_tree_ref *full_ref,
-		 int action),
-
-	TP_ARGS(ref, full_ref, action),
-
-	TP_FIELDS(
-		ctf_integer(u64, bytenr, ref->bytenr)
-		ctf_integer(u64, num_bytes, ref->num_bytes)
-		ctf_integer(int, action, action)
-		ctf_integer(u64, parent, full_ref->parent)
-		ctf_integer(u64, ref_root, full_ref->root)
-		ctf_integer(int, level, full_ref->level)
-		ctf_integer(int, type, ref->type)
-	)
-)
 #endif
 
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,10,0))
@@ -1487,7 +1470,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs_delayed_data_ref,
 
 	TP_ARGS(fs_info, ref, full_ref, action)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
+#else
 LTTNG_TRACEPOINT_EVENT_CLASS(btrfs_delayed_data_ref,
 
 	TP_PROTO(struct btrfs_delayed_ref_node *ref,
@@ -1534,47 +1517,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs_delayed_data_ref,
 
 	TP_ARGS(fs_info, ref, full_ref, action)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,7,0))
-LTTNG_TRACEPOINT_EVENT(btrfs_delayed_data_ref,
-
-	TP_PROTO(struct btrfs_delayed_ref_node *ref,
-		 struct btrfs_delayed_data_ref *full_ref,
-		 int action),
-
-	TP_ARGS(ref, full_ref, action),
-
-	TP_FIELDS(
-		ctf_integer(u64, bytenr, ref->bytenr)
-		ctf_integer(u64, num_bytes, ref->num_bytes)
-		ctf_integer(int, action, action)
-		ctf_integer(u64, parent, full_ref->parent)
-		ctf_integer(u64, ref_root, full_ref->root)
-		ctf_integer(u64, owner, full_ref->objectid)
-		ctf_integer(u64, offset, full_ref->offset)
-		ctf_integer(int, type, ref->type)
-		ctf_integer(u64, seq, ref->seq)
-	)
-)
-#else
-LTTNG_TRACEPOINT_EVENT(btrfs_delayed_data_ref,
-
-	TP_PROTO(struct btrfs_delayed_ref_node *ref,
-		 struct btrfs_delayed_data_ref *full_ref,
-		 int action),
-
-	TP_ARGS(ref, full_ref, action),
-
-	TP_FIELDS(
-		ctf_integer(u64, bytenr, ref->bytenr)
-		ctf_integer(u64, num_bytes, ref->num_bytes)
-		ctf_integer(int, action, action)
-		ctf_integer(u64, parent, full_ref->parent)
-		ctf_integer(u64, ref_root, full_ref->root)
-		ctf_integer(u64, owner, full_ref->objectid)
-		ctf_integer(u64, offset, full_ref->offset)
-		ctf_integer(int, type, ref->type)
-	)
-)
 #endif
 
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,15,0))
@@ -1763,7 +1705,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs_delayed_ref_head,
 	TP_ARGS(ref, head_ref, action)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
+#else
 LTTNG_TRACEPOINT_EVENT_CLASS(btrfs_delayed_ref_head,
 
 	TP_PROTO(struct btrfs_delayed_ref_node *ref,
@@ -1805,23 +1747,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs_delayed_ref_head,
 
 	TP_ARGS(ref, head_ref, action)
 )
-
-#else
-LTTNG_TRACEPOINT_EVENT(btrfs_delayed_ref_head,
-
-	TP_PROTO(struct btrfs_delayed_ref_node *ref,
-		 struct btrfs_delayed_ref_head *head_ref,
-		 int action),
-
-	TP_ARGS(ref, head_ref, action),
-
-	TP_FIELDS(
-		ctf_integer(u64, bytenr, ref->bytenr)
-		ctf_integer(u64, num_bytes, ref->num_bytes)
-		ctf_integer(int, action, action)
-		ctf_integer(int, is_data, head_ref->is_data)
-	)
-)
 #endif
 
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,8,0))
@@ -2004,25 +1929,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__chunk,  btrfs_chunk_free,
 
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,17,0) || \
-	LTTNG_KERNEL_RANGE(6,16,4, 6,17,0))
-LTTNG_TRACEPOINT_EVENT(btrfs_cow_block,
-
-	TP_PROTO(const struct btrfs_root *root, const struct extent_buffer *buf,
-		 const struct extent_buffer *cow),
-
-	TP_ARGS(root, buf, cow),
-
-	TP_FIELDS(
-		ctf_integer(u64, root_objectid, root->root_key.objectid)
-		ctf_integer(u64, buf_start, buf->start)
-		ctf_integer(int, refs, refcount_read(&buf->refs))
-		ctf_integer(u64, cow_start, cow->start)
-		ctf_integer(int, buf_level, btrfs_header_level(buf))
-		ctf_integer(int, cow_level, btrfs_header_level(cow))
-	)
-)
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,73,5,0,0, 4,4,73,6,0,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,82,6,0,0, 4,4,82,7,0,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,92,6,0,0, 4,4,92,7,0,0) || \
@@ -2098,7 +2005,7 @@ LTTNG_TRACEPOINT_EVENT(btrfs_space_reservation,
 		ctf_integer(int, reserve, reserve)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#else
 LTTNG_TRACEPOINT_EVENT(btrfs_space_reservation,
 
 	TP_PROTO(struct btrfs_fs_info *fs_info, char *type, u64 val,
@@ -2390,7 +2297,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(find_free_extent,
 		ctf_integer(u64, data, data)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#else
 
 LTTNG_TRACEPOINT_EVENT_MAP(find_free_extent,
 
@@ -2622,7 +2529,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__reserve_extent, btrfs_reserve_extent_clus
 	TP_ARGS(root, block_group, start, len)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#else
 
 LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__reserve_extent,
 
@@ -2755,7 +2662,7 @@ LTTNG_TRACEPOINT_EVENT(btrfs_setup_cluster,
 		ctf_integer(int, bitmap, bitmap)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#else
 LTTNG_TRACEPOINT_EVENT(btrfs_find_cluster,
 
 	TP_PROTO(struct btrfs_block_group_cache *block_group, u64 start,
@@ -2835,7 +2742,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(free_extent_state,
 		ctf_integer_hex(unsigned long, ip, IP)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
+#else
 LTTNG_TRACEPOINT_EVENT_MAP(alloc_extent_state,
 
 	btrfs_alloc_extent_state,
