@@ -1,4 +1,7 @@
-/* SPDX-License-Identifier: GPL-2.0-only */
+// SPDX-FileCopyrightText: 2012 Paul Woegerer <paul_woegerer@mentor.com>
+//
+// SPDX-License-Identifier: GPL-2.0-only
+
 #undef TRACE_SYSTEM
 #define TRACE_SYSTEM scsi
 
@@ -212,8 +215,7 @@
 		scsi_opcode_name(ATA_16),			\
 		scsi_opcode_name(ATA_12))
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0) \
-	|| LTTNG_RHEL_KERNEL_RANGE(3,10,0,327,0,0, 3,11,0,0,0,0))
+#else
 
 #define show_opcode_name(val)					\
 	__print_symbolic(val,					\
@@ -310,104 +312,7 @@
 		scsi_opcode_name(ATA_16),			\
 		scsi_opcode_name(ATA_12))
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0)) */
-
-#define show_opcode_name(val)					\
-	__print_symbolic(val,					\
-		scsi_opcode_name(TEST_UNIT_READY),		\
-		scsi_opcode_name(REZERO_UNIT),			\
-		scsi_opcode_name(REQUEST_SENSE),		\
-		scsi_opcode_name(FORMAT_UNIT),			\
-		scsi_opcode_name(READ_BLOCK_LIMITS),		\
-		scsi_opcode_name(REASSIGN_BLOCKS),		\
-		scsi_opcode_name(INITIALIZE_ELEMENT_STATUS),	\
-		scsi_opcode_name(READ_6),			\
-		scsi_opcode_name(WRITE_6),			\
-		scsi_opcode_name(SEEK_6),			\
-		scsi_opcode_name(READ_REVERSE),			\
-		scsi_opcode_name(WRITE_FILEMARKS),		\
-		scsi_opcode_name(SPACE),			\
-		scsi_opcode_name(INQUIRY),			\
-		scsi_opcode_name(RECOVER_BUFFERED_DATA),	\
-		scsi_opcode_name(MODE_SELECT),			\
-		scsi_opcode_name(RESERVE),			\
-		scsi_opcode_name(RELEASE),			\
-		scsi_opcode_name(COPY),				\
-		scsi_opcode_name(ERASE),			\
-		scsi_opcode_name(MODE_SENSE),			\
-		scsi_opcode_name(START_STOP),			\
-		scsi_opcode_name(RECEIVE_DIAGNOSTIC),		\
-		scsi_opcode_name(SEND_DIAGNOSTIC),		\
-		scsi_opcode_name(ALLOW_MEDIUM_REMOVAL),		\
-		scsi_opcode_name(SET_WINDOW),			\
-		scsi_opcode_name(READ_CAPACITY),		\
-		scsi_opcode_name(READ_10),			\
-		scsi_opcode_name(WRITE_10),			\
-		scsi_opcode_name(SEEK_10),			\
-		scsi_opcode_name(POSITION_TO_ELEMENT),		\
-		scsi_opcode_name(WRITE_VERIFY),			\
-		scsi_opcode_name(VERIFY),			\
-		scsi_opcode_name(SEARCH_HIGH),			\
-		scsi_opcode_name(SEARCH_EQUAL),			\
-		scsi_opcode_name(SEARCH_LOW),			\
-		scsi_opcode_name(SET_LIMITS),			\
-		scsi_opcode_name(PRE_FETCH),			\
-		scsi_opcode_name(READ_POSITION),		\
-		scsi_opcode_name(SYNCHRONIZE_CACHE),		\
-		scsi_opcode_name(LOCK_UNLOCK_CACHE),		\
-		scsi_opcode_name(READ_DEFECT_DATA),		\
-		scsi_opcode_name(MEDIUM_SCAN),			\
-		scsi_opcode_name(COMPARE),			\
-		scsi_opcode_name(COPY_VERIFY),			\
-		scsi_opcode_name(WRITE_BUFFER),			\
-		scsi_opcode_name(READ_BUFFER),			\
-		scsi_opcode_name(UPDATE_BLOCK),			\
-		scsi_opcode_name(READ_LONG),			\
-		scsi_opcode_name(WRITE_LONG),			\
-		scsi_opcode_name(CHANGE_DEFINITION),		\
-		scsi_opcode_name(WRITE_SAME),			\
-		scsi_opcode_name(UNMAP),			\
-		scsi_opcode_name(READ_TOC),			\
-		scsi_opcode_name(LOG_SELECT),			\
-		scsi_opcode_name(LOG_SENSE),			\
-		scsi_opcode_name(XDWRITEREAD_10),		\
-		scsi_opcode_name(MODE_SELECT_10),		\
-		scsi_opcode_name(RESERVE_10),			\
-		scsi_opcode_name(RELEASE_10),			\
-		scsi_opcode_name(MODE_SENSE_10),		\
-		scsi_opcode_name(PERSISTENT_RESERVE_IN),	\
-		scsi_opcode_name(PERSISTENT_RESERVE_OUT),	\
-		scsi_opcode_name(VARIABLE_LENGTH_CMD),		\
-		scsi_opcode_name(REPORT_LUNS),			\
-		scsi_opcode_name(MAINTENANCE_IN),		\
-		scsi_opcode_name(MAINTENANCE_OUT),		\
-		scsi_opcode_name(MOVE_MEDIUM),			\
-		scsi_opcode_name(EXCHANGE_MEDIUM),		\
-		scsi_opcode_name(READ_12),			\
-		scsi_opcode_name(WRITE_12),			\
-		scsi_opcode_name(WRITE_VERIFY_12),		\
-		scsi_opcode_name(SEARCH_HIGH_12),		\
-		scsi_opcode_name(SEARCH_EQUAL_12),		\
-		scsi_opcode_name(SEARCH_LOW_12),		\
-		scsi_opcode_name(READ_ELEMENT_STATUS),		\
-		scsi_opcode_name(SEND_VOLUME_TAG),		\
-		scsi_opcode_name(WRITE_LONG_2),			\
-		scsi_opcode_name(READ_16),			\
-		scsi_opcode_name(WRITE_16),			\
-		scsi_opcode_name(VERIFY_16),			\
-		scsi_opcode_name(WRITE_SAME_16),		\
-		scsi_opcode_name(SERVICE_ACTION_IN),		\
-		scsi_opcode_name(SAI_READ_CAPACITY_16),		\
-		scsi_opcode_name(SAI_GET_LBA_STATUS),		\
-		scsi_opcode_name(MI_REPORT_TARGET_PGS),		\
-		scsi_opcode_name(MO_SET_TARGET_PGS),		\
-		scsi_opcode_name(READ_32),			\
-		scsi_opcode_name(WRITE_32),			\
-		scsi_opcode_name(WRITE_SAME_32),		\
-		scsi_opcode_name(ATA_16),			\
-		scsi_opcode_name(ATA_12))
-
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0)) */
+#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,7,0)) */
 
 #define scsi_hostbyte_name(result)	{ result, #result }
 #define show_hostbyte_name(val)					\
