@@ -79,13 +79,10 @@ struct channel_backend {
 					 */
 	unsigned int buf_size_order;	/* Order of buffer size */
 	unsigned int extra_reader_sb:1;	/* has extra reader subbuffer ? */
-	union {
-		struct lttng_kernel_ring_buffer *global_buf;	/* Channel global buffer */
-		struct lttng_kernel_ring_buffer __percpu *percpu_buf;	/* Channel per-cpu buffers */
-	};
+	struct lttng_kernel_ring_buffer *buf;	/* Channel per-cpu buffers */
 
 	unsigned long num_subbuf;	/* Number of sub-buffers for writer */
-	u64 start_tsc;			/* Channel creation TSC value */
+	u64 start_timestamp;		/* Channel creation timestamp value */
 	void *priv;			/* Client-specific information */
 	void *priv_ops;			/* Client-specific ops pointer */
 	void (*release_priv_ops)(void *priv_ops);
