@@ -82,7 +82,14 @@ struct commit_counters_hot {
 
 /* Per-subbuffer commit counters used only on cold paths */
 struct commit_counters_cold {
-	union v_atomic cc_sb;		/* Incremented _once_ at sb switch */
+	union v_atomic cc_sb;			/* Incremented _once_ at sb switch */
+	unsigned long end_events_discarded;	/*
+						* Passing events discarded counter
+						* read upon try_reserve and try_switch
+						* that fills a subbuffer to check_deliver
+						* so it can be written into the packet
+						* header field.
+						*/
 };
 
 /* Per-buffer read iterator */
@@ -115,7 +122,7 @@ struct lttng_kernel_ring_buffer {
 					 */
 	atomic_t record_disabled;
 	/* End of first 32 bytes cacheline */
-	union v_atomic last_tsc;	/*
+	union v_atomic last_timestamp;	/*
 					 * Last timestamp written in the buffer.
 					 */
 
