@@ -61,7 +61,7 @@ int lib_ring_buffer_backend_allocate(const struct lttng_kernel_ring_buffer_confi
 	 * end up running out of memory because of this buffer allocation, we
 	 * want to kill the offending app first.
 	 */
-	wrapper_set_current_oom_origin();
+	set_current_oom_origin();
 
 	num_pages_per_subbuf = num_pages >> get_count_order(num_subbuf);
 	subbuf_size = chanb->subbuf_size;
@@ -157,7 +157,7 @@ int lib_ring_buffer_backend_allocate(const struct lttng_kernel_ring_buffer_confi
 	 * will not fault.
 	 */
 	wrapper_vmalloc_sync_mappings();
-	wrapper_clear_current_oom_origin();
+	clear_current_oom_origin();
 	vfree(pages);
 	return 0;
 
@@ -174,7 +174,7 @@ depopulate:
 array_error:
 	vfree(pages);
 pages_error:
-	wrapper_clear_current_oom_origin();
+	clear_current_oom_origin();
 not_enough_pages:
 	return -ENOMEM;
 }
@@ -256,7 +256,7 @@ void channel_backend_reset(struct channel_backend *chanb)
 	 * num_subbuf_order, buf_size_order, extra_reader_sb, num_subbuf,
 	 * priv, notifiers, config, cpumask and name.
 	 */
-	chanb->start_tsc = config->cb.ring_buffer_clock_read(chan);
+	chanb->start_timestamp = config->cb.ring_buffer_clock_read(chan);
 }
 
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0))
@@ -277,9 +277,9 @@ int lttng_cpuhp_rb_backend_prepare(unsigned int cpu,
 	struct lttng_kernel_ring_buffer *buf;
 	int ret;
 
-	CHAN_WARN_ON(chanb, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chanb, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
-	buf = per_cpu_ptr(chanb->percpu_buf, cpu);
+	buf = per_cpu_ptr(chanb->buf, cpu);
 	ret = lib_ring_buffer_create(buf, chanb, cpu);
 	if (ret) {
 		printk(KERN_ERR
@@ -315,12 +315,12 @@ int lib_ring_buffer_cpu_hp_callback(struct notifier_block *nb,
 	struct lttng_kernel_ring_buffer *buf;
 	int ret;
 
-	CHAN_WARN_ON(chanb, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chanb, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	switch (action) {
 	case CPU_UP_PREPARE:
 	case CPU_UP_PREPARE_FROZEN:
-		buf = per_cpu_ptr(chanb->percpu_buf, cpu);
+		buf = per_cpu_ptr(chanb->buf, cpu);
 		ret = lib_ring_buffer_create(buf, chanb, cpu);
 		if (ret) {
 			printk(KERN_ERR
@@ -405,11 +405,7 @@ int channel_backend_init(struct channel_backend *chanb,
 	chanb->extra_reader_sb =
 			(config->mode == RING_BUFFER_OVERWRITE) ? 1 : 0;
 	chanb->num_subbuf = num_subbuf;
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,8,0))
 	strscpy(chanb->name, name, NAME_MAX);
-#else
-	strlcpy(chanb->name, name, NAME_MAX);
-#endif
 	memcpy(&chanb->config, config, sizeof(chanb->config));
 
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU) {
@@ -419,8 +415,8 @@ int channel_backend_init(struct channel_backend *chanb,
 
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU) {
 		/* Allocating the buffer per-cpu structures */
-		chanb->percpu_buf = alloc_percpu(struct lttng_kernel_ring_buffer);
-		if (!chanb->percpu_buf)
+		chanb->buf = alloc_percpu(struct lttng_kernel_ring_buffer);
+		if (!chanb->buf)
 			goto free_cpumask;
 
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0))
@@ -451,7 +447,7 @@ int channel_backend_init(struct channel_backend *chanb,
 
 			lttng_cpus_read_lock();
 			for_each_online_cpu(i) {
-				ret = lib_ring_buffer_create(per_cpu_ptr(chanb->percpu_buf, i),
+				ret = lib_ring_buffer_create(per_cpu_ptr(chanb->buf, i),
 							 chanb, i);
 				if (ret)
 					goto free_bufs;	/* cpu hotplug locked */
@@ -459,7 +455,7 @@ int channel_backend_init(struct channel_backend *chanb,
 			lttng_cpus_read_unlock();
 #else
 			for_each_possible_cpu(i) {
-				ret = lib_ring_buffer_create(per_cpu_ptr(chanb->percpu_buf, i),
+				ret = lib_ring_buffer_create(per_cpu_ptr(chanb->buf, i),
 							 chanb, i);
 				if (ret)
 					goto free_bufs;
@@ -468,14 +464,14 @@ int channel_backend_init(struct channel_backend *chanb,
 		}
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
 	} else {
-		chanb->global_buf = kzalloc(sizeof(struct lttng_kernel_ring_buffer), GFP_KERNEL);
-		if (!chanb->global_buf)
+		chanb->buf = kzalloc(sizeof(struct lttng_kernel_ring_buffer), GFP_KERNEL);
+		if (!chanb->buf)
 			goto free_cpumask;
-		ret = lib_ring_buffer_create(chanb->global_buf, chanb, -1);
+		ret = lib_ring_buffer_create(chanb->buf, chanb, -1);
 		if (ret)
 			goto free_bufs;
 	}
-	chanb->start_tsc = config->cb.ring_buffer_clock_read(chan);
+	chanb->start_timestamp = config->cb.ring_buffer_clock_read(chan);
 
 	return 0;
 
@@ -495,15 +491,15 @@ free_bufs:
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
 		for_each_possible_cpu(i) {
 			struct lttng_kernel_ring_buffer *buf =
-				per_cpu_ptr(chanb->percpu_buf, i);
+				per_cpu_ptr(chanb->buf, i);
 
 			if (!buf->backend.allocated)
 				continue;
 			lib_ring_buffer_free(buf);
 		}
-		free_percpu(chanb->percpu_buf);
+		free_percpu(chanb->buf);
 	} else
-		kfree(chanb->global_buf);
+		kfree(chanb->buf);
 free_cpumask:
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU)
 		free_cpumask_var(chanb->cpumask);
@@ -546,16 +542,16 @@ void channel_backend_free(struct channel_backend *chanb)
 
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU) {
 		for_each_possible_cpu(i) {
-			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chanb->percpu_buf, i);
+			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chanb->buf, i);
 
 			if (!buf->backend.allocated)
 				continue;
 			lib_ring_buffer_free(buf);
 		}
 		free_cpumask_var(chanb->cpumask);
-		free_percpu(chanb->percpu_buf);
+		free_percpu(chanb->buf);
 	} else {
-		struct lttng_kernel_ring_buffer *buf = chanb->global_buf;
+		struct lttng_kernel_ring_buffer *buf = chanb->buf;
 
 		CHAN_WARN_ON(chanb, !buf->backend.allocated);
 		lib_ring_buffer_free(buf);
