@@ -37,21 +37,25 @@
  *   - put_subbuf
  */
 
+#include <linux/atomic.h>
 #include <linux/delay.h>
 #include <linux/module.h>
 #include <linux/percpu.h>
+#include <linux/percpu-defs.h>
 #include <asm/cacheflush.h>
 
+#include <lttng/abi.h>
+#include <lttng/events.h>
+#include <lttng/events-internal.h>
 #include <ringbuffer/config.h>
 #include <ringbuffer/backend.h>
 #include <ringbuffer/frontend.h>
 #include <ringbuffer/iterator.h>
 #include <ringbuffer/nohz.h>
-#include <wrapper/atomic.h>
 #include <wrapper/cpu.h>
 #include <wrapper/kref.h>
-#include <wrapper/percpu-defs.h>
 #include <wrapper/timer.h>
+#include <wrapper/trace-clock.h>
 #include <wrapper/vmalloc.h>
 
 /*
@@ -85,6 +89,14 @@ void lib_ring_buffer_print_errors(struct lttng_kernel_ring_buffer_channel *chan,
 static
 void _lib_ring_buffer_switch_remote(struct lttng_kernel_ring_buffer *buf,
 		enum switch_mode mode);
+static
+int _lib_ring_buffer_switch_remote_or_populate_packet(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *buf,
+		void __user *packet,
+		u64 *packet_length,
+		u64 *packet_length_padded,
+		bool *flush_done,
+		bool *packet_populated);
 
 static
 int lib_ring_buffer_poll_deliver(const struct lttng_kernel_ring_buffer_config *config,
@@ -169,11 +181,12 @@ void lib_ring_buffer_reset(struct lttng_kernel_ring_buffer *buf)
 		v_set(config, &buf->commit_hot[i].cc, 0);
 		v_set(config, &buf->commit_hot[i].seq, 0);
 		v_set(config, &buf->commit_cold[i].cc_sb, 0);
+		buf->commit_cold[i].end_events_discarded = 0;
 		buf->ts_end[i] = 0;
 	}
 	atomic_long_set(&buf->consumed, 0);
 	atomic_set(&buf->record_disabled, 0);
-	v_set(config, &buf->last_tsc, 0);
+	v_set(config, &buf->last_timestamp, 0);
 	lib_ring_buffer_backend_reset(&buf->backend);
 	/* Don't reset number of active readers */
 	v_set(config, &buf->records_lost_full, 0);
@@ -232,7 +245,7 @@ int lib_ring_buffer_create(struct lttng_kernel_ring_buffer *buf,
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(chanb, struct lttng_kernel_ring_buffer_channel, backend);
 	void *priv = chanb->priv;
 	size_t subbuf_header_size;
-	u64 tsc;
+	u64 timestamp;
 	int ret;
 
 	/* Test for cpu hotplug */
@@ -294,8 +307,8 @@ int lib_ring_buffer_create(struct lttng_kernel_ring_buffer *buf,
 	subbuf_header_size = config->cb.subbuffer_header_size();
 	v_set(config, &buf->offset, subbuf_header_size);
 	subbuffer_id_clear_noref(config, &buf->backend.buf_wsb[0].id);
-	tsc = config->cb.ring_buffer_clock_read(buf->backend.chan);
-	config->cb.buffer_begin(buf, tsc, 0);
+	timestamp = config->cb.ring_buffer_clock_read(buf->backend.chan);
+	config->cb.buffer_begin(buf, timestamp, 0);
 	v_add(config, subbuf_header_size, &buf->commit_hot[0].cc);
 
 	if (config->cb.buffer_create) {
@@ -492,10 +505,10 @@ int lttng_cpuhp_rb_frontend_dead(unsigned int cpu,
 {
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(node, struct lttng_kernel_ring_buffer_channel,
 					    cpuhp_prepare);
-	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf, cpu);
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
-	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	/*
 	 * Performing a buffer switch on a remote CPU. Performed by
@@ -513,10 +526,10 @@ int lttng_cpuhp_rb_frontend_online(unsigned int cpu,
 {
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(node, struct lttng_kernel_ring_buffer_channel,
 					    cpuhp_online);
-	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf, cpu);
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
-	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	wake_up_interruptible(&chan->hp_wait);
 	lib_ring_buffer_start_switch_timer(buf);
@@ -530,10 +543,10 @@ int lttng_cpuhp_rb_frontend_offline(unsigned int cpu,
 {
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(node, struct lttng_kernel_ring_buffer_channel,
 					    cpuhp_online);
-	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf, cpu);
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
-	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	lib_ring_buffer_stop_switch_timer(buf);
 	lib_ring_buffer_stop_read_timer(buf);
@@ -561,13 +574,13 @@ int lib_ring_buffer_cpu_hp_callback(struct notifier_block *nb,
 	unsigned int cpu = (unsigned long)hcpu;
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(nb, struct lttng_kernel_ring_buffer_channel,
 					    cpu_hp_notifier);
-	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf, cpu);
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
 	if (!chan->cpu_hp_enable)
 		return NOTIFY_DONE;
 
-	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	switch (action) {
 	case CPU_DOWN_FAILED:
@@ -626,11 +639,11 @@ static int notrace ring_buffer_tick_nohz_callback(struct notifier_block *nb,
 
 	if (config->alloc != RING_BUFFER_ALLOC_PER_CPU) {
 		/*
-		 * We don't support keeping the system idle with global buffers
-		 * and streaming active. In order to do so, we would need to
-		 * sample a non-nohz-cpumask racelessly with the nohz updates
-		 * without adding synchronization overhead to nohz. Leave this
-		 * use-case out for now.
+		 * We don't support keeping the system idle with per-channel
+		 * buffers and streaming active. In order to do so, we would
+		 * need to sample a non-nohz-cpumask racelessly with the nohz
+		 * updates without adding synchronization overhead to
+		 * nohz. Leave this use-case out for now.
 		 */
 		return 0;
 	}
@@ -652,16 +665,16 @@ static int notrace ring_buffer_tick_nohz_callback(struct notifier_block *nb,
 		raw_spin_unlock(&buf->raw_tick_nohz_spinlock);
 		break;
 	case TICK_NOHZ_STOP:
-		spin_lock(lttng_this_cpu_ptr(&ring_buffer_nohz_lock));
+		spin_lock(this_cpu_ptr(&ring_buffer_nohz_lock));
 		lib_ring_buffer_stop_switch_timer(buf);
 		lib_ring_buffer_stop_read_timer(buf);
-		spin_unlock(lttng_this_cpu_ptr(&ring_buffer_nohz_lock));
+		spin_unlock(this_cpu_ptr(&ring_buffer_nohz_lock));
 		break;
 	case TICK_NOHZ_RESTART:
-		spin_lock(lttng_this_cpu_ptr(&ring_buffer_nohz_lock));
+		spin_lock(this_cpu_ptr(&ring_buffer_nohz_lock));
 		lib_ring_buffer_start_read_timer(buf);
 		lib_ring_buffer_start_switch_timer(buf);
-		spin_unlock(lttng_this_cpu_ptr(&ring_buffer_nohz_lock));
+		spin_unlock(this_cpu_ptr(&ring_buffer_nohz_lock));
 		break;
 	}
 
@@ -728,7 +741,7 @@ static void channel_unregister_notifiers(struct lttng_kernel_ring_buffer_channel
 			lttng_cpus_read_lock();
 			chan->cpu_hp_enable = 0;
 			for_each_online_cpu(cpu) {
-				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 								      cpu);
 				lib_ring_buffer_stop_switch_timer(buf);
 				lib_ring_buffer_stop_read_timer(buf);
@@ -737,7 +750,7 @@ static void channel_unregister_notifiers(struct lttng_kernel_ring_buffer_channel
 			unregister_cpu_notifier(&chan->cpu_hp_notifier);
 #else
 			for_each_possible_cpu(cpu) {
-				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 								      cpu);
 				lib_ring_buffer_stop_switch_timer(buf);
 				lib_ring_buffer_stop_read_timer(buf);
@@ -746,7 +759,7 @@ static void channel_unregister_notifiers(struct lttng_kernel_ring_buffer_channel
 		}
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
 	} else {
-		struct lttng_kernel_ring_buffer *buf = chan->backend.global_buf;
+		struct lttng_kernel_ring_buffer *buf = chan->backend.buf;
 
 		lib_ring_buffer_stop_switch_timer(buf);
 		lib_ring_buffer_stop_read_timer(buf);
@@ -775,14 +788,14 @@ void lib_ring_buffer_set_quiescent_channel(struct lttng_kernel_ring_buffer_chann
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU) {
 		lttng_cpus_read_lock();
 		for_each_channel_cpu(cpu, chan) {
-			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 							      cpu);
 
 			lib_ring_buffer_set_quiescent(buf);
 		}
 		lttng_cpus_read_unlock();
 	} else {
-		struct lttng_kernel_ring_buffer *buf = chan->backend.global_buf;
+		struct lttng_kernel_ring_buffer *buf = chan->backend.buf;
 
 		lib_ring_buffer_set_quiescent(buf);
 	}
@@ -797,14 +810,14 @@ void lib_ring_buffer_clear_quiescent_channel(struct lttng_kernel_ring_buffer_cha
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU) {
 		lttng_cpus_read_lock();
 		for_each_channel_cpu(cpu, chan) {
-			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 							      cpu);
 
 			lib_ring_buffer_clear_quiescent(buf);
 		}
 		lttng_cpus_read_unlock();
 	} else {
-		struct lttng_kernel_ring_buffer *buf = chan->backend.global_buf;
+		struct lttng_kernel_ring_buffer *buf = chan->backend.buf;
 
 		lib_ring_buffer_clear_quiescent(buf);
 	}
@@ -902,7 +915,7 @@ struct lttng_kernel_ring_buffer_channel *channel_create(const struct lttng_kerne
 
 			lttng_cpus_read_lock();
 			for_each_online_cpu(cpu) {
-				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 								       cpu);
 				spin_lock(&per_cpu(ring_buffer_nohz_lock, cpu));
 				lib_ring_buffer_start_switch_timer(buf);
@@ -913,7 +926,7 @@ struct lttng_kernel_ring_buffer_channel *channel_create(const struct lttng_kerne
 			lttng_cpus_read_unlock();
 #else
 			for_each_possible_cpu(cpu) {
-				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+				struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 								      cpu);
 				spin_lock(&per_cpu(ring_buffer_nohz_lock, cpu));
 				lib_ring_buffer_start_switch_timer(buf);
@@ -934,7 +947,7 @@ struct lttng_kernel_ring_buffer_channel *channel_create(const struct lttng_kerne
 #endif /* defined(CONFIG_NO_HZ) && defined(CONFIG_LIB_RING_BUFFER) */
 
 	} else {
-		struct lttng_kernel_ring_buffer *buf = chan->backend.global_buf;
+		struct lttng_kernel_ring_buffer *buf = chan->backend.buf;
 
 		lib_ring_buffer_start_switch_timer(buf);
 		lib_ring_buffer_start_read_timer(buf);
@@ -991,7 +1004,7 @@ void *channel_destroy(struct lttng_kernel_ring_buffer_channel *chan)
 		 * unregistered.
 		 */
 		for_each_channel_cpu(cpu, chan) {
-			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf,
+			struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf,
 							      cpu);
 
 			if (config->cb.buffer_finalize)
@@ -1006,7 +1019,7 @@ void *channel_destroy(struct lttng_kernel_ring_buffer_channel *chan)
 			wake_up_interruptible(&buf->read_wait);
 		}
 	} else {
-		struct lttng_kernel_ring_buffer *buf = chan->backend.global_buf;
+		struct lttng_kernel_ring_buffer *buf = chan->backend.buf;
 
 		if (config->cb.buffer_finalize)
 			config->cb.buffer_finalize(buf, chan->backend.priv, -1);
@@ -1030,10 +1043,10 @@ struct lttng_kernel_ring_buffer *channel_get_ring_buffer(
 					const struct lttng_kernel_ring_buffer_config *config,
 					struct lttng_kernel_ring_buffer_channel *chan, int cpu)
 {
-	if (config->alloc == RING_BUFFER_ALLOC_GLOBAL)
-		return chan->backend.global_buf;
+	if (config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL)
+		return chan->backend.buf;
 	else
-		return per_cpu_ptr(chan->backend.percpu_buf, cpu);
+		return per_cpu_ptr(chan->backend.buf, cpu);
 }
 EXPORT_SYMBOL_GPL(channel_get_ring_buffer);
 
@@ -1047,7 +1060,7 @@ int lib_ring_buffer_open_read(struct lttng_kernel_ring_buffer *buf)
 		atomic_long_dec(&buf->active_readers);
 		return -EOVERFLOW;
 	}
-	lttng_smp_mb__after_atomic();
+	smp_mb__after_atomic();
 	return 0;
 }
 EXPORT_SYMBOL_GPL(lib_ring_buffer_open_read);
@@ -1057,7 +1070,7 @@ void lib_ring_buffer_release_read(struct lttng_kernel_ring_buffer *buf)
 	struct lttng_kernel_ring_buffer_channel *chan = buf->backend.chan;
 
 	CHAN_WARN_ON(chan, atomic_long_read(&buf->active_readers) != 1);
-	lttng_smp_mb__before_atomic();
+	smp_mb__before_atomic();
 	atomic_long_dec(&buf->active_readers);
 	kref_put(&chan->ref, channel_release);
 }
@@ -1210,6 +1223,16 @@ static void lib_ring_buffer_flush_read_subbuf_dcache(
 	if (config->output != RING_BUFFER_MMAP)
 		return;
 
+#ifdef cpu_dcache_is_aliasing
+	/*
+	 * Some architectures implement flush_dcache_page() but don't
+	 * actually have aliasing dcache. cpu_dcache_is_aliasing() was
+	 * introduced in kernel v6.9 to query this more precisely.
+	 */
+	if (!cpu_dcache_is_aliasing())
+		return;
+#endif
+
 	/*
 	 * Architectures with caches aliased on virtual addresses may
 	 * use different cache lines for the linear mapping vs
@@ -1595,7 +1618,7 @@ void lib_ring_buffer_switch_old_start(struct lttng_kernel_ring_buffer *buf,
 	unsigned long commit_count;
 	struct commit_counters_hot *cc_hot;
 
-	config->cb.buffer_begin(buf, ctx->priv.tsc, oldidx);
+	config->cb.buffer_begin(buf, ctx->priv.timestamp, oldidx);
 
 	/*
 	 * Order all writes to buffer before the commit count update that will
@@ -1654,7 +1677,11 @@ void lib_ring_buffer_switch_old_end(struct lttng_kernel_ring_buffer *buf,
 	 * postponed until the commit counter is incremented for the
 	 * current space reservation.
 	 */
-	*ts_end = ctx->priv.tsc;
+	*ts_end = ctx->priv.timestamp;
+	buf->commit_cold[oldidx].end_events_discarded =
+		lib_ring_buffer_get_records_lost_full(config, ctx) +
+		lib_ring_buffer_get_records_lost_wrap(config, ctx) +
+		lib_ring_buffer_get_records_lost_big(config, ctx);
 
 	/*
 	 * Order all writes to buffer and store to ts_end before the commit
@@ -1697,7 +1724,7 @@ void lib_ring_buffer_switch_new_start(struct lttng_kernel_ring_buffer *buf,
 	unsigned long commit_count;
 	struct commit_counters_hot *cc_hot;
 
-	config->cb.buffer_begin(buf, ctx->priv.tsc, beginidx);
+	config->cb.buffer_begin(buf, ctx->priv.timestamp, beginidx);
 
 	/*
 	 * Order all writes to buffer before the commit count update that will
@@ -1753,7 +1780,11 @@ void lib_ring_buffer_switch_new_end(struct lttng_kernel_ring_buffer *buf,
 	 * postponed until the commit counter is incremented for the
 	 * current space reservation.
 	 */
-	*ts_end = ctx->priv.tsc;
+	*ts_end = ctx->priv.timestamp;
+	buf->commit_cold[endidx].end_events_discarded =
+		lib_ring_buffer_get_records_lost_full(config, ctx) +
+		lib_ring_buffer_get_records_lost_wrap(config, ctx) +
+		lib_ring_buffer_get_records_lost_big(config, ctx);
 }
 
 /*
@@ -1776,7 +1807,7 @@ int lib_ring_buffer_try_switch_slow(enum switch_mode mode,
 	offsets->switch_old_start = 0;
 	off = subbuf_offset(offsets->begin, chan);
 
-	ctx->priv.tsc = config->cb.ring_buffer_clock_read(chan);
+	ctx->priv.timestamp = config->cb.ring_buffer_clock_read(chan);
 
 	/*
 	 * Ensure we flush the header of an empty subbuffer when doing the
@@ -1897,12 +1928,12 @@ void lib_ring_buffer_switch_slow(struct lttng_kernel_ring_buffer *buf, enum swit
 		 != offsets.old);
 
 	/*
-	 * Atomically update last_tsc. This update races against concurrent
-	 * atomic updates, but the race will always cause supplementary full TSC
-	 * records, never the opposite (missing a full TSC record when it would
-	 * be needed).
+	 * Atomically update last_timestamp. This update races against concurrent
+	 * atomic updates, but the race will always cause supplementary
+	 * full timestamp records, never the opposite (missing a full
+	 * timestamp record when it would be needed).
 	 */
-	save_last_tsc(config, buf, ctx.priv.tsc);
+	save_last_timestamp(config, buf, ctx.priv.timestamp);
 
 	/*
 	 * Push the reader if necessary
@@ -1949,9 +1980,9 @@ static void _lib_ring_buffer_switch_remote(struct lttng_kernel_ring_buffer *buf,
 	struct switch_param param;
 
 	/*
-	 * With global synchronization we don't need to use the IPI scheme.
+	 * With per-channel synchronization we don't need to use the IPI scheme.
 	 */
-	if (config->sync == RING_BUFFER_SYNC_GLOBAL) {
+	if (config->sync == RING_BUFFER_SYNC_PER_CHANNEL) {
 		lib_ring_buffer_switch_slow(buf, mode);
 		return;
 	}
@@ -1976,6 +2007,59 @@ static void _lib_ring_buffer_switch_remote(struct lttng_kernel_ring_buffer *buf,
 	preempt_enable();
 }
 
+static
+int _lib_ring_buffer_switch_remote_or_populate_packet(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *buf,
+		void __user *packet,
+		u64 *_packet_length,
+		u64 *_packet_length_padded,
+		bool *_flush_done,
+		bool *_packet_populated)
+{
+	u64 sample_seq_cnt, sample_time, packet_length = 0, packet_length_padded = 0;
+	unsigned long consumed, produced, consumed_after, produced_after;
+	bool flush_done = false, packet_populated = false;
+	size_t subbuf_idx;
+	int ret = 0;
+
+	/* Sample positions and time prior to flushing */
+	ret = lib_ring_buffer_snapshot_sample_positions(buf, &consumed, &produced);
+	if (ret < 0)
+		return ret;
+
+	sample_time = trace_clock_read64();
+	subbuf_idx = subbuf_index(produced, buf->backend.chan);
+	/*
+	 * Expected to be updated concurrently by subbuffer_inc_packet_count(),
+	 * but validated by comparing the two samples of the produced position.
+	 */
+	sample_seq_cnt = READ_ONCE(buf->backend.buf_cnt[subbuf_idx].seq_cnt);
+	lib_ring_buffer_switch_remote(buf);
+	flush_done = true;
+
+	/* Re-sample positions */
+	ret = lib_ring_buffer_snapshot_sample_positions(buf, &consumed_after, &produced_after);
+	if (ret < 0)
+		goto end;
+
+	if (produced == produced_after) {
+		ret = lib_ring_buffer_packet_initialize(config, buf, packet,
+				sample_time, sample_time, sample_seq_cnt + 1,
+				&packet_length, &packet_length_padded);
+		if (ret)
+			goto end;
+
+		packet_populated = true;
+	}
+
+end:
+	*_packet_length = packet_length;
+	*_packet_length_padded = packet_length_padded;
+	*_flush_done = flush_done;
+	*_packet_populated = packet_populated;
+	return ret;
+}
+
 /* Switch sub-buffer if current sub-buffer is non-empty. */
 void lib_ring_buffer_switch_remote(struct lttng_kernel_ring_buffer *buf)
 {
@@ -1990,6 +2074,20 @@ void lib_ring_buffer_switch_remote_empty(struct lttng_kernel_ring_buffer *buf)
 }
 EXPORT_SYMBOL_GPL(lib_ring_buffer_switch_remote_empty);
 
+/* Switch sub-buffer if current sub-buffer is non-empty or populate a packet. */
+int lib_ring_buffer_switch_remote_or_populate_packet(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *buf,
+		void __user *packet,
+		u64 *packet_length,
+		u64 *packet_length_padded,
+		bool *flush_done,
+		bool *packet_populated)
+{
+	return _lib_ring_buffer_switch_remote_or_populate_packet(config, buf, packet,
+		packet_length, packet_length_padded, flush_done, packet_populated);
+}
+EXPORT_SYMBOL_GPL(lib_ring_buffer_switch_remote_or_populate_packet);
+
 void lib_ring_buffer_clear(struct lttng_kernel_ring_buffer *buf)
 {
 	struct lttng_kernel_ring_buffer_backend *bufb = &buf->backend;
@@ -2025,12 +2123,12 @@ retry:
 	offsets->switch_old_end = 0;
 	offsets->pre_header_padding = 0;
 
-	ctx->priv.tsc = config->cb.ring_buffer_clock_read(chan);
-	if ((int64_t) ctx->priv.tsc == -EIO)
+	ctx->priv.timestamp = config->cb.ring_buffer_clock_read(chan);
+	if ((int64_t) ctx->priv.timestamp == -EIO)
 		return -EIO;
 
-	if (last_tsc_overflow(config, buf, ctx->priv.tsc))
-		ctx->priv.rflags |= RING_BUFFER_RFLAG_FULL_TSC;
+	if (last_timestamp_overflow(config, buf, ctx->priv.timestamp))
+		ctx->priv.rflags |= RING_BUFFER_RFLAG_FULL_TIMESTAMP;
 
 	if (unlikely(subbuf_offset(offsets->begin, ctx->priv.chan) == 0)) {
 		offsets->switch_new_start = 1;		/* For offsets->begin */
@@ -2173,9 +2271,9 @@ static struct lttng_kernel_ring_buffer *get_current_buf(struct lttng_kernel_ring
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
 	if (config->alloc == RING_BUFFER_ALLOC_PER_CPU)
-		return per_cpu_ptr(chan->backend.percpu_buf, cpu);
+		return per_cpu_ptr(chan->backend.buf, cpu);
 	else
-		return chan->backend.global_buf;
+		return chan->backend.buf;
 }
 
 void lib_ring_buffer_lost_event_too_big(struct lttng_kernel_ring_buffer_channel *chan)
@@ -2217,12 +2315,12 @@ int lib_ring_buffer_reserve_slow(struct lttng_kernel_ring_buffer_ctx *ctx,
 			  != offsets.old));
 
 	/*
-	 * Atomically update last_tsc. This update races against concurrent
-	 * atomic updates, but the race will always cause supplementary full TSC
-	 * records, never the opposite (missing a full TSC record when it would
-	 * be needed).
+	 * Atomically update last_timestamp. This update races against concurrent
+	 * atomic updates, but the race will always cause supplementary
+	 * full timestamp records, never the opposite (missing a full
+	 * timestamp record when it would be needed).
 	 */
-	save_last_tsc(config, buf, ctx->priv.tsc);
+	save_last_timestamp(config, buf, ctx->priv.timestamp);
 
 	/*
 	 * Push the reader if necessary
@@ -2412,6 +2510,25 @@ void lib_ring_buffer_check_deliver_slow(const struct lttng_kernel_ring_buffer_co
 }
 EXPORT_SYMBOL_GPL(lib_ring_buffer_check_deliver_slow);
 
+int lib_ring_buffer_packet_initialize(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *buf,
+		void __user *packet,
+		uint64_t timestamp_begin,
+		uint64_t timestamp_end,
+		uint64_t sequence_number,
+		uint64_t *packet_length,
+		uint64_t *packet_length_padded)
+{
+	struct lttng_kernel_ring_buffer_channel *chan = buf->backend.chan;
+	const struct lttng_kernel_channel_buffer_ops *ops = chan->backend.priv_ops;
+	const struct lttng_kernel_channel_buffer_ops_private *priv_ops = ops->priv;
+
+	return priv_ops->user_packet_initialize(config, buf, packet,
+		timestamp_begin, timestamp_end, sequence_number,
+		packet_length, packet_length_padded);
+}
+EXPORT_SYMBOL_GPL(lib_ring_buffer_packet_initialize);
+
 static
 int __init init_lib_ring_buffer_frontend(void)
 {
