@@ -11,7 +11,7 @@
 
 #include <ringbuffer/iterator.h>
 #include <wrapper/cpu.h>
-#include <wrapper/file.h>
+#include <linux/file.h>
 #include <wrapper/uaccess.h>
 #include <linux/jiffies.h>
 #include <linux/delay.h>
@@ -48,9 +48,9 @@ restart:
 	case ITER_GET_SUBBUF:
 		ret = lib_ring_buffer_get_next_subbuf(buf);
 		if (ret && !LTTNG_READ_ONCE(buf->finalized)
-		    && config->alloc == RING_BUFFER_ALLOC_GLOBAL) {
+		    && config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL) {
 			/*
-			 * Use "pull" scheme for global buffers. The reader
+			 * Use "pull" scheme for per-channel buffers. The reader
 			 * itself flushes the buffer to "pull" data not visible
 			 * to readers yet. Flush current subbuffer and re-try.
 			 *
@@ -247,7 +247,7 @@ ssize_t channel_get_next_record(struct lttng_kernel_ring_buffer_channel *chan,
 	struct lttng_ptr_heap *heap;
 	ssize_t len;
 
-	if (config->alloc == RING_BUFFER_ALLOC_GLOBAL) {
+	if (config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL) {
 		*ret_buf = channel_get_ring_buffer(config, chan, 0);
 		return lib_ring_buffer_get_next_record(chan, *ret_buf);
 	}
@@ -361,10 +361,10 @@ int lttng_cpuhp_rb_iter_online(unsigned int cpu,
 {
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(node, struct lttng_kernel_ring_buffer_channel,
 					    cpuhp_iter_online);
-	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf, cpu);
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
-	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	lib_ring_buffer_iterator_init(chan, buf);
 	return 0;
@@ -382,13 +382,13 @@ int channel_iterator_cpu_hotplug(struct notifier_block *nb,
 	unsigned int cpu = (unsigned long)hcpu;
 	struct lttng_kernel_ring_buffer_channel *chan = container_of(nb, struct lttng_kernel_ring_buffer_channel,
 					    hp_iter_notifier);
-	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+	struct lttng_kernel_ring_buffer *buf = per_cpu_ptr(chan->backend.buf, cpu);
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
 	if (!chan->hp_iter_enable)
 		return NOTIFY_DONE;
 
-	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_GLOBAL);
+	CHAN_WARN_ON(chan, config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL);
 
 	switch (action) {
 	case CPU_DOWN_FAILED:
@@ -443,14 +443,14 @@ int channel_iterator_init(struct lttng_kernel_ring_buffer_channel *chan)
 
 			lttng_cpus_read_lock();
 			for_each_online_cpu(cpu) {
-				buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+				buf = per_cpu_ptr(chan->backend.buf, cpu);
 				lib_ring_buffer_iterator_init(chan, buf);
 			}
 			chan->hp_iter_enable = 1;
 			lttng_cpus_read_unlock();
 #else
 			for_each_possible_cpu(cpu) {
-				buf = per_cpu_ptr(chan->backend.percpu_buf, cpu);
+				buf = per_cpu_ptr(chan->backend.buf, cpu);
 				lib_ring_buffer_iterator_init(chan, buf);
 			}
 #endif
@@ -743,7 +743,7 @@ ssize_t lib_ring_buffer_file_read(struct file *filp,
 			          size_t count,
 			          loff_t *ppos)
 {
-	struct inode *inode = filp->lttng_f_dentry->d_inode;
+	struct inode *inode = filp->f_path.dentry->d_inode;
 	struct lttng_kernel_ring_buffer *buf = inode->i_private;
 	struct lttng_kernel_ring_buffer_channel *chan = buf->backend.chan;
 
@@ -768,7 +768,7 @@ ssize_t channel_file_read(struct file *filp,
 			  size_t count,
 			  loff_t *ppos)
 {
-	struct inode *inode = filp->lttng_f_dentry->d_inode;
+	struct inode *inode = filp->f_path.dentry->d_inode;
 	struct lttng_kernel_ring_buffer_channel *chan = inode->i_private;
 	const struct lttng_kernel_ring_buffer_config *config = &chan->backend.config;
 
