@@ -9,6 +9,8 @@
  *
  */
 
+#ifdef CONFIG_PID_NS
+
 #include <linux/module.h>
 #include <linux/slab.h>
 #include <linux/sched.h>
@@ -17,12 +19,8 @@
 #include <lttng/events-internal.h>
 #include <ringbuffer/frontend_types.h>
 #include <wrapper/vmalloc.h>
-#include <wrapper/namespace.h>
 #include <lttng/tracer.h>
 
-#if defined(CONFIG_PID_NS) && \
-	(LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
-
 static
 size_t pid_ns_get_size(void *priv, struct lttng_kernel_probe_ctx *probe_ctx, size_t offset)
 {
@@ -49,7 +47,7 @@ void pid_ns_record(void *priv, struct lttng_kernel_probe_ctx *probe_ctx,
 	ns = task_active_pid_ns(current);
 
 	if (ns)
-		pid_ns_inum = ns->lttng_ns_inum;
+		pid_ns_inum = ns->ns.inum;
 
 	chan->ops->event_write(ctx, &pid_ns_inum, sizeof(pid_ns_inum), lttng_alignof(pid_ns_inum));
 }
@@ -70,7 +68,7 @@ void pid_ns_get_value(void *priv,
 	ns = task_active_pid_ns(current);
 
 	if (ns)
-		pid_ns_inum = ns->lttng_ns_inum;
+		pid_ns_inum = ns->ns.inum;
 
 	value->u.s64 = pid_ns_inum;
 }
