@@ -86,7 +86,7 @@ static size_t client_packet_header_size(void)
 	return offsetof(struct event_notifier_packet_header, header_end);
 }
 
-static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 tsc,
+static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 timestamp,
 				unsigned int subbuf_idx)
 {
 }
@@ -95,7 +95,7 @@ static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 tsc,
  * offset is assumed to never be 0 here : never deliver a completely empty
  * subbuffer. data_size is between 1 and subbuf_size.
  */
-static void client_buffer_end(struct lttng_kernel_ring_buffer *buf, u64 tsc,
+static void client_buffer_end(struct lttng_kernel_ring_buffer *buf, u64 timestamp,
 			      unsigned int subbuf_idx, unsigned long data_size,
 			      const struct lttng_kernel_ring_buffer_ctx *ctx)
 {
@@ -200,9 +200,9 @@ static const struct lttng_kernel_ring_buffer_config client_config = {
 	.cb.buffer_finalize = client_buffer_finalize,
 	.cb.record_get = client_record_get,
 
-	.tsc_bits = 0,
-	.alloc = RING_BUFFER_ALLOC_GLOBAL,
-	.sync = RING_BUFFER_SYNC_GLOBAL,
+	.timestamp_bits = 0,
+	.alloc = RING_BUFFER_ALLOC_PER_CHANNEL,
+	.sync = RING_BUFFER_SYNC_PER_CHANNEL,
 	.mode = RING_BUFFER_MODE_TEMPLATE,
 	.backend = RING_BUFFER_PAGE,
 	.output = RING_BUFFER_OUTPUT_TEMPLATE,
@@ -363,7 +363,7 @@ size_t lttng_packet_avail_size(struct lttng_kernel_ring_buffer_channel *chan)
 	unsigned long o_begin;
 	struct lttng_kernel_ring_buffer *buf;
 
-	buf = chan->backend.global_buf;	/* Only for global buffer ! */
+	buf = chan->backend.buf;	/* Only for global buffer ! */
 	o_begin = v_read(&client_config, &buf->offset);
 	if (subbuf_offset(o_begin, chan) != 0) {
 		return chan->backend.subbuf_size - subbuf_offset(o_begin, chan);
